@@ -1,7 +1,6 @@
-""" Pylama's core functionality.
+"""Pylama's core functionality.
 
 Prepare params, check a modeline and run the checkers.
-
 """
 import logging
 
@@ -12,7 +11,7 @@ from .lint.extensions import LINTERS
 
 
 def run(path='', code=None, rootdir=CURDIR, options=None):
-    """ Run code checkers with given params.
+    """Run code checkers with given params.
 
     :param path: (str) A file's path.
     :param code: (str) A code source
@@ -21,10 +20,11 @@ def run(path='', code=None, rootdir=CURDIR, options=None):
     """
     errors = []
     fileconfig = dict()
-    lname = 'undefined'
-    params = dict()
     linters = LINTERS
     linters_params = dict()
+    lname = 'undefined'
+    params = dict()
+    path = op.relpath(path, rootdir)
 
     if options:
         linters = options.linters
@@ -33,9 +33,12 @@ def run(path='', code=None, rootdir=CURDIR, options=None):
             if mask.match(path):
                 fileconfig.update(options.file_params[mask])
 
+        if options.skip and any(p.match(path) for p in options.skip):
+            LOGGER.info('Skip checking for path: %s', path)
+            return []
+
     try:
         with CodeContext(code, path) as ctx:
-            path = op.relpath(path, rootdir)
             code = ctx.code
             params = prepare_params(parse_modeline(code), fileconfig, options)
             LOGGER.debug('Checking params: %s', params)
@@ -56,11 +59,12 @@ def run(path='', code=None, rootdir=CURDIR, options=None):
                 lparams = linters_params.get(lname, dict())
                 LOGGER.info("Run %s %s", lname, lparams)
 
-                for er in linter.run(
-                        path, code=code, ignore=params.get("ignore", set()),
-                        select=params.get("select", set()), params=lparams):
-                    errors.append(Error(
-                        filename=path, linter=lname, **er))
+                linter_errors = linter.run(
+                    path, code=code, ignore=params.get("ignore", set()),
+                    select=params.get("select", set()), params=lparams)
+                if linter_errors:
+                    for er in linter_errors:
+                        errors.append(Error(filename=path, linter=lname, **er))
 
     except IOError as e:
         LOGGER.debug("IOError %s", e)
@@ -69,14 +73,15 @@ def run(path='', code=None, rootdir=CURDIR, options=None):
     except SyntaxError as e:
         LOGGER.debug("SyntaxError %s", e)
         errors.append(
-            Error(linter=lname, lnum=e.lineno, col=e.offset, text=e.args[0],
+            Error(linter='pylama', lnum=e.lineno, col=e.offset,
+                  text='E0100 SyntaxError: {}'.format(e.args[0]),
                   filename=path))
 
-    except Exception as e:
+    except Exception as e: # noqa
         import traceback
         LOGGER.info(traceback.format_exc())
 
-    errors = filter_errors(errors, **params)
+    errors = filter_errors(errors, **params)  # noqa
 
     errors = list(remove_duplicates(errors))
 
@@ -91,7 +96,7 @@ def run(path='', code=None, rootdir=CURDIR, options=None):
 
 
 def parse_modeline(code):
-    """ Parse params from file's modeline.
+    """Parse params from file's modeline.
 
     :return dict: Linter params.
 
@@ -104,15 +109,15 @@ def parse_modeline(code):
 
 
 def prepare_params(modeline, fileconfig, options):
-    """ Prepare and merge a params from modelines and configs.
+    """Prepare and merge a params from modelines and configs.
 
     :return dict:
 
     """
     params = dict(skip=False, ignore=[], select=[], linters=[])
     if options:
-        params['ignore'] = options.ignore[:]
-        params['select'] = options.select[:]
+        params['ignore'] = list(options.ignore)
+        params['select'] = list(options.select)
 
     for config in filter(None, [modeline, fileconfig]):
         for key in ('ignore', 'select', 'linters'):
@@ -126,7 +131,7 @@ def prepare_params(modeline, fileconfig, options):
 
 
 def filter_errors(errors, select=None, ignore=None, **params):
-    """ Filter a erros by select and ignore options.
+    """Filter a erros by select and ignore options.
 
     :return bool:
 
@@ -148,7 +153,7 @@ def filter_errors(errors, select=None, ignore=None, **params):
 
 
 def filter_skiplines(code, errors):
-    """ Filter lines by `noqa`.
+    """Filter lines by `noqa`.
 
     :return list: A filtered errors
 
@@ -169,8 +174,7 @@ def filter_skiplines(code, errors):
 
 
 class CodeContext(object):
-
-    """ Read file if code is None. """
+    """Read file if code is None. """
 
     def __init__(self, code, path):
         """ Init context. """
@@ -194,4 +198,4 @@ class CodeContext(object):
         if t and LOGGER.level == logging.DEBUG:
             LOGGER.debug(traceback)
 
-# pylama:ignore=R0912
+# pylama:ignore=R0912,D210,F0001
