@@ -3,7 +3,7 @@ from __future__ import absolute_import
 
 from os import path as op
 
-import py
+import py # noqa
 import pytest
 
 
@@ -43,7 +43,7 @@ class PylamaItem(pytest.Item, pytest.File):
 
     def __init__(self, path, parent):
         super(PylamaItem, self).__init__(path, parent)
-        self.add_marker("pep8")
+        self.add_marker("pycodestyle")
         self.cache = None
         self._pylamamtimes = None
 
@@ -59,11 +59,12 @@ class PylamaItem(pytest.Item, pytest.File):
             pytest.skip("file(s) previously passed Pylama checks")
 
     def runtest(self):
-        call = py.io.StdCapture.call
-        errors, out, err = call(check_file, self.fspath)
-        # errors = check_file(self.fspath)
+        errors = check_file(self.fspath)
         if errors:
-            raise PylamaError(out, err)
+            pattern = "%(filename)s:%(lnum)s:%(col)s: %(text)s"
+            out = "\n".join([pattern % e._info for e in errors])
+            raise PylamaError(out)
+
         # update mtime only if test passed
         # otherwise failures would not be re-run next time
         if self.cache:
@@ -83,4 +84,4 @@ def check_file(path):
     path = op.relpath(str(path), CURDIR)
     return process_paths(options, candidates=[path], error=False)
 
-# pylama:ignore=D,E1002,W0212
+# pylama:ignore=D,E1002,W0212,F0001
